# Reference Catalog: Best Practices
### On this page
  * [Creating Fact Sheets Using the Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog-best-practices#creating-fact-sheets-using-the-reference-catalog)
  * [Linking Existing Fact Sheets to the Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog-best-practices#linking-existing-fact-sheets-to-the-reference-catalog)
  * [Ignored and Unlinked Fact Sheets](https://help.sap.com/docs/leanix/ea/reference-catalog-best-practices#ignored-and-unlinked-fact-sheets)
  * [Reporting Missing Data](https://help.sap.com/docs/leanix/ea/reference-catalog-best-practices#reporting-missing-data)
  * [Reporting a Mistake in Fact Sheet Metadata](https://help.sap.com/docs/leanix/ea/reference-catalog-best-practices#reporting-a-mistake-in-fact-sheet-metadata)


Best practices for efficiently using the reference catalog.
